Output

Trait Output 

pub trait Output<'a, SampleSpace: CoordinateSpace>: Sample<'a, SampleSpace> {
    type Error;
    type Controls: Brightness + GammaCorrected;

    // Required methods
    fn commit(&mut self) -> Result<(), Self::Error>;
    fn controls(&mut self) -> Option<&mut Self::Controls>;
}
A hardware output that provides an interface to the underlying hardware pixels, including actually turning pixels into photons

Required Associated Types

Required Methods

fn commit(&mut self) -> Result<(), Self::Error>

Commits the contents of the underlying pixel buffers to hardware

fn controls(&mut self) -> Option<&mut Self::Controls>

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors

Source

impl<'a, T: SmartLedsWrite + 'a, Pixbuf: AsRef<[T::Color]>> Output<'a, LinearSpace> for SmartLedsOutput<'a, T, Pixbuf>
where Self: Sample<'a, LinearSpace>, T::Color: Debug + AsMilliwatts + Mul<Fract8, Output = T::Color> + Copy + WithGamma,