PowerManagedWriter

Struct PowerManagedWriter 

pub struct PowerManagedWriter<T> { /* private fields */ }

Implementations

Source

impl<T> PowerManagedWriter<T>

pub fn new(target: T, max_mw: Milliwatts) -> Self

pub fn write<P: AsRef<[T::Color]> + ?Sized>( &mut self, pixbuf: &P, ) -> Result<(), T::Error>
where T: SmartLedsWrite, T::Color: Mul<Fract8, Output = T::Color> + Copy + WithGamma + AsMilliwatts + Debug,

pub async fn write_async<P: AsRef<[T::Color]> + ?Sized>( &mut self, pixbuf: &P, ) -> Result<(), T::Error>

pub fn controls(&mut self) -> &mut PowerControls

pub const fn max_mw(&self) -> u32

Returns the total power required to display the previous write at full brightness. This is /not/ the actual power consumption, only a theoretical maximum useful for designing power supplies.