pub trait Output<'a, SampleSpace: CoordinateSpace>: Sample<'a, SampleSpace> {
type Error;
type Controls: Brightness + GammaCorrected;
// Required methods
fn commit(&mut self) -> Result<(), Self::Error>;
fn controls(&mut self) -> Option<&mut Self::Controls>;
}Expand description
A hardware output that provides an interface to the underlying hardware pixels, including actually turning pixels into photons
Required Associated Types
type Error
type Controls: Brightness + GammaCorrected
Required Methods
Sourcefn commit(&mut self) -> Result<(), Self::Error>
fn commit(&mut self) -> Result<(), Self::Error>
Commits the contents of the underlying pixel buffers to hardware
fn controls(&mut self) -> Option<&mut Self::Controls>
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.